@@ -3,7 +3,7 @@
 #' \code{auth} asks the API's server for a session ID (SID), which you can then
 #' pass along to either \code{\link{query_wos}} or \code{\link{pull_wos}}. Note,
 #' there are limits on how many session IDs you can get in a given period of time
-#' (roughly 5 SIDs in a 5 minute time period).
+#' (roughly 5 SIDs in a 5 minute period).
 #'
 #' @param username Your username. Specify \code{username = NULL} if you want to
 #' use IP-based authentication.
@@ -18,7 +18,7 @@
 #' # Pass user credentials in manually:
 #' auth("some_username", password = "some_password")
 #'
-#' # Use default of looking for username and password in envvars, so you
+#' # Use the default of looking for username and password in envvars, so you
 #' # don't have to keep specifying them in your code:
 #' Sys.setenv(WOS_USERNAME = "some_username", WOS_PASSWORD = "some_password")
 #' auth()
@@ -26,12 +26,15 @@
 #' @export
 auth <- function(username = Sys.getenv("WOS_USERNAME"),
                  password = Sys.getenv("WOS_PASSWORD")) {
+  ip_based <- is.null(username) && is.null(password)
 
-  if (username == "" || password == "") {
-    stop(
-      "You need to provide a username and password to use the API",
-      call. = FALSE
-    )
+  if (!ip_based) {
+    if (username == "" || password == "") {
+      stop(
+        "You need to provide a username and password to use the API",
+        call. = FALSE
+      )
+    }
   }
 
   body <-
@@ -64,10 +67,7 @@ auth <- function(username = Sys.getenv("WOS_USERNAME"),
   }
 
   # Confirm server didn't throw an error
-  check_resp(
-    response,
-    message = "Received the following error when authenticating with server:\n\n"
-  )
+  check_resp(response)
 
   # Pull out SID from XML
   doc <- get_xml(response)
