@@ -1,6 +1,6 @@
-check_resp <- function(response, message) {
+check_resp <- function(response) {
   if (httr::http_error(response)) {
-    stop(message, parse_er(response), call. = FALSE)
+    stop(parse_er(response), call. = FALSE)
   }
 }
 
@@ -25,3 +25,24 @@ format_num <- function(x) format(
 )
 
 append_class <- function(x, class) structure(x, class = c(class(x), class))
+
+trim_uts <- function(x) gsub("^WOS:", "", x, ignore.case = TRUE)
+
+retry_throttle <- function(expr) {
+  tryCatch(
+    expr = expr,
+    error = function(e) {
+      throt_er <- grepl(
+        "throttle|limit of [0-9] requests per period", e$message,
+        ignore.case = TRUE
+      )
+      if (throt_er) {
+        Sys.sleep(3)
+        message("\nRan into throttling error. Sleeping and trying again.")
+        expr
+      } else {
+        stop(e$message)
+      }
+    }
+  )
+}
