@@ -1,7 +1,6 @@
-context("Incites client")
+context("InCites")
 
 test_that("pull_incites works for a small number of uts", {
-
   skip_if_no_auth()
   uts <- c(
     "000269886100018", "000272059500002", "000265594300007",
@@ -10,5 +9,4 @@ test_that("pull_incites works for a small number of uts", {
   )
   out_incites <- pull_incites(uts)
   expect_true(nrow(out_incites) == length(uts))
-
 })
